@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.4100';
+our $VERSION = '0.4101';
 
 use strictures 2;
 use Data::Dumper::Compact qw(ddc);
@@ -622,7 +622,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.4100
+version 0.4101
 
 =head1 SYNOPSIS
 
@@ -635,7 +635,7 @@ version 0.4100
     signature => '5/4',
     bars      => 8,
     reverb    => 0,
-    kit       => 25, # TR-808 if using GM Level 2
+    #kit   => 25, # TR-808 if using GM Level 2
     #kick  => 36, # Override default patch
     #snare => 40, # "
  );
@@ -655,21 +655,24 @@ version 0.4100
  $d->note($d->sixteenth, $d->crash1);
  $d->accent_note(127, $d->sixteenth, $d->crash2);
 
+ my $patterns = [ $d->euclidean(5, 16), $d->euclidean(7, 16) ];
+ $d->pattern( instrument => $d->kick, patterns => $patterns );
+
  # Alternate kick and snare
  $d->note($d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare)
     for 1 .. $d->beats * $d->bars;
 
- print 'Count: ', $d->counter, "\n";
-
  # Same but with beat-strings:
  $d->sync_patterns(
     $d->open_hh => [ '1111' ],
     $d->snare   => [ '0101' ],
     $d->kick    => [ '1010' ],
- ) for 1 .. $d->bars ;
+ ) for 1 .. $d->bars - 1;
 
- my $patterns = [ $d->euclidean(5, 16), $d->euclidean(7, 16) ];
- $d->pattern( instrument => $d->kick, patterns => $patterns );
+ # Add a fill to the end of the phrase!
+ $d->add_fill('...');
+
+ print 'Count: ', $d->counter, "\n";
 
  $d->write;
 
@@ -1100,15 +1103,22 @@ the file name.
 =head1 SEE ALSO
 
 The F<t/*> test file and the F<eg/*> programs in this distribution.
+
 Also F<eg/drum-fills-advanced> in the L<Music::Duration::Partition>
 distribution.
 
+L<Data::Dumper::Compact>
+
+L<List::Util>
+
 L<Math::Bezier>
 
 L<MIDI::Util>
 
 L<Moo>
 
+L<Music::CreatingRhythms>
+
 L<Music::Duration>
 
 L<Music::RhythmSet::Util>
